@@ -1,4 +1,5 @@
-evalSolution <- function (frame, outstrata, 
+evalSolution <- function (frame, 
+                          outstrata, 
                           nsampl = 100, 
                           cens = NULL, 
                           writeFiles = TRUE,
@@ -10,6 +11,7 @@ evalSolution <- function (frame, outstrata,
     if(!dir.exists(direnew)) dir.create(direnew)
     setwd(direnew)
   }
+  colnames(frame) <- toupper(colnames(frame))
   numY <- length(grep("Y", toupper(colnames(frame))))
   numdom <- length(levels(as.factor(frame$DOMAINVALUE)))
   param <- array(0, c(numY, numdom))
@@ -137,14 +139,16 @@ evalSolution <- function (frame, outstrata,
   } 
   bias$dom <- paste("DOM", c(1:numdom), sep = "")
   bias <- as.data.frame(bias)
+  Y <- aggregate(frame[,grep("Y",colnames(frame))],by=list(frame$DOMAINVALUE),mean)
+  numY <- sum(grepl("Y",colnames(frame)))
+  bias <- round(bias[,c(1:numY)]/Y[,c(2:(numY+1))],4)
   if (writeFiles == TRUE)
     write.table(bias, "expected_rel_bias.csv", sep = ",",
                 row.names = FALSE, col.names = TRUE, quote = FALSE)
-############################################  
   if (numdom > 1) {
     if (writeFiles == TRUE) 
-    # pdf("cv.pdf", width = 7, height = 5)
-    png("cv.png")
+      # pdf("cv.pdf", width = 7, height = 5)
+      png("cv.png")
     boxplot(val ~ cv, data = cv1, col = "orange", main = "Distribution of CV's in the domains", 
             xlab = "Variables Y", ylab = "Value of CV")
     if (writeFiles == TRUE) 
@@ -152,7 +156,9 @@ evalSolution <- function (frame, outstrata,
     if (writeFiles == TRUE) 
       # pdf("rel_bias.pdf", width = 7, height = 5)
       png("rel_bias.png")
-    boxplot(bias[,-ncol(bias)], col = "orange", main = "Distribution of relative bias in the domains", 
+    # boxplot(bias[,-ncol(bias)], col = "orange", main = "Distribution of relative bias in the domains", 
+    #         xlab = "Variables Y", ylab = "Relative bias")
+    boxplot(bias, col = "orange", main = "Distribution of relative bias in the domains", 
             xlab = "Variables Y", ylab = "Relative bias")
     if (writeFiles == TRUE) 
       dev.off()
@@ -181,7 +187,24 @@ evalSolution <- function (frame, outstrata,
   # if (writeFiles == TRUE) 
   #   dev.off()
   # results <- list(coeff_var = cv1, bias = bias1)
-  results <- list(coeff_var = cv, rel_bias = bias)
+  est <- matrix(NA,nrow=numdom*nsampl,ncol=numY)
+  est <- as.data.frame(est) 
+  colnames(est) <- c(paste("Y",c(1:numY),sep=""))
+  est$dom <- rep(c(1:numdom),each=nsampl)
+  for (i in (1:numdom)) {
+    est[est$dom == i,c(1:(numY))] <- estim[i,,]
+  }
+  if (writeFiles == TRUE) {
+    write.table(est,"estimates.csv",sep=",",row.names=F,col.names=F)
+  }
+  cv <- round(cv[,c(1:numY)],4)
+  cv <- cbind(c(1:nrow(cv)),cv)
+  colnames(cv) <- c("domain",paste("cv(Y",c(1:numY),")",sep=""))
+  bias <- cbind(c(1:nrow(bias)),bias)
+  colnames(bias) <- c("domain",paste("bias(Y",c(1:numY),")",sep=""))
+  cv <- formattable(cv,list(area(col = 2:(numY+1)) ~ color_tile("#DeF7E9", "#71CA97")))
+  bias <- formattable(bias,list(area(col = 2:(numY+1)) ~ color_tile("#DeF7E9", "#71CA97")))
+  results <- list(coeff_var = cv, rel_bias = bias, est = est)
   if (writeFiles == TRUE) {
     setwd(dire)
   }
